% rossreturnmap.m
% program calculates return map in the radial coordinate using 
% fourth order Runge-Kutta scheme and "Henon's trick"

clc; close all; clear all;
format long e;

n=3;
crit=6.01201;
ang=(230/180)*pi;% defines theta coordinate of the section

y(1)=crit*cos(ang);  % initial
y(2)=crit*sin(ang);  % values
y(3)=.020073;
t=0.0;
K=0;
count=0;
h=.001;  % time step !!if you change here, change in RK4 also!!
skip=1;  % used to ignore testing for return map condition
stop=30;
tan_c=tan(ang);  % don't use if ang~pi/2 or ~3pi/2 
                 % instead use cot_c
                 
datafile1=('knead.txt');       % file for kneading sequence
kneaddata=fopen(datafile1,'w');
Kseq(1,1)=crit;

while (count<stop)
    
    yout=RK4(y);
    
    if ((y(2)>=0)&(yout(2)<=0)) % !!change these conditions anytime
        skip=0;                 % you change 'ang'!! 
    end
            
    if ((yout(2)<=0)&(yout(1)<=0)&(skip==0)) % !!condition depends on which
                                 % quadrant the section (i.e., 'ang') is in!!
    ttan=y(2)/y(1);  % use to compare against tan_c
    ttanout=yout(2)/yout(1);
    
        if ((ttan<tan_c)&(ttanout>tan_c))   % implies traj crossed  
             yout=retRK4pol(y,t,ang);  % integrate using radial
                                       % coordinate and Henon's trick
             t=yout(2);   % switch t and theta back
             yout(2)=ang; % make theta the coord of the section
             if(yout(1)>crit)
                 seq=1;
             end
             
             if(yout(1)<crit)
                 seq=0;
             end
             
             fprintf(kneaddata, '%d\n', seq);
             count=count+1;
             
             Kseq(K+1,2)=yout(1);
             if(count~=stop)
             Kseq(K+2,1)=yout(1);   
             Kseq(K+2,2)=yout(1);   
             Kseq(K+3,1)=yout(1);
             end
             K=K+2;
             rad=yout(1);  % used to convert from cylindrical to cartesian
             thet=yout(2);
     
             skip=1;           
             yout(1)=rad*cos(thet); % convert back to cartesian coords
             yout(2)=rad*sin(thet);
             y=yout;
             
        elseif (ttan==tan_c) % if landed on the section on prev step
             rad=sqrt(y(1)^2+y(2)^2); % don't advance time
             if(yout(1)>crit)
                 seq=1;
             end
             
             if(yout(1)<crit)
                 seq=0;
             end
             fprintf(kneaddata, '%d\n', seq);
             count=count+1;
             
             Kseq(K+1,2)=yout(1);
             if(count~=stop)
             Kseq(K+2,1)=yout(1);   
             Kseq(K+2,2)=yout(1);   
             Kseq(K+3,1)=yout(1);
             end
             K=K+2;
             
             skip=1;
             
        elseif (ttanout==tan_c) % if landed on the section on the current 
             rad=sqrt(yout(1)^2+yout(2)^2); % step must advance time
             if(yout(1)>crit)
                 seq=1;
             end
             
             if(yout(1)<crit)
                 seq=0;
             end
             fprintf(kneaddata, '%d\n', seq);
             count=count+1;
             
             Kseq(K+1,2)=yout(1);
             if(count~=stop)
             Kseq(K+2,1)=yout(1);   
             Kseq(K+2,2)=yout(1);   
             Kseq(K+3,1)=yout(1);
             end
             K=K+2;
             
             y=yout;
             t=t+h;
             skip=1;
             
        else
             t=t+h;
             y=yout;
        end
    
    else
        t=t+h;
        y=yout;
    end
    
end

filename5='ret230.txt';
data5=fopen(filename5);
retpts=fscanf(data5,'%g',[1,inf])';
iter=size(retpts,1);
for w=1:iter-1  % creates array for return map plot
    data55(w,1)=retpts(w);  
    data55(w,2)=retpts(w+1);
end
plot(data55(:,1),data55(:,2),'k.',Kseq(:,1),Kseq(:,2),'b-') % plots R_(n+1) vs R_(n)
grid on;
axis on;
xlabel('R(n)');
ylabel('R(n+1)');

fclose(kneaddata);